"
jv:vdb - Visual / VM Debugger
Copyright (C) 2015-now Jan Vrany

This software is licensed under 'Creative Commons Attribution-NonCommercial 4.0 International License'

You may find a full license text in LICENSE.txt or at http://creativecommons.org/licenses/by-nc/4.0/
"
"{ Package: 'jv:vdb' }"

"{ NameSpace: Smalltalk }"

LibraryDefinition subclass:#jv_vdb
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'* Projects & Packages *'
!

!jv_vdb class methodsFor:'documentation'!

copyright
"
jv:vdb - Visual / VM Debugger
Copyright (C) 2015-now Jan Vrany

This software is licensed under 'Creative Commons Attribution-NonCommercial 4.0 International License'

You may find a full license text in LICENSE.txt or at http://creativecommons.org/licenses/by-nc/4.0/
"
! !

!jv_vdb class methodsFor:'description'!

excludedFromPreRequisites
    "list packages which are to be explicitely excluded from the automatic constructed
     prerequisites list. If empty, everything that is found along the inheritance of any of
     my classes is considered to be a prerequisite package."

    ^ #(
    )
!

mandatoryPreRequisites
    "list packages which are mandatory as a prerequisite.
     This are packages containing superclasses of my classes and classes which
     are extended by myself.
     They are mandatory, because we need these packages as a prerequisite for loading and compiling.
     This method is generated automatically,
     by searching along the inheritance chain of all of my classes.
     Please take a look at the #referencedPreRequisites method as well."

    ^ #(
        #'jv:libgdbs'    "GDBCommandStatus - shared pool used by VDBWindowsDebuggerConsoleApplication"
        #'stx:libbasic'    "Collection - extended"
        #'stx:libtool'    "AbstractSettingsApplication - superclass of VDBSettingsApplication"
        #'stx:libview'    "DisplaySurface - superclass of VDBWindowsDebuggerConsoleView"
        #'stx:libview2'    "ApplicationModel - superclass of VDBAbstractApplication"
        #'stx:libwidg'    "EditTextView - superclass of VDBWindowsDebuggerConsoleView"
        #'stx:libwidg2'    "AbstractHierarchicalItem - superclass of VDBAbstractPresenter"
    )
!

referencedPreRequisites
    "list packages which are a prerequisite, because they contain
     classes which are referenced by my classes.
     These packages are NOT needed as a prerequisite for compiling or loading,
     however, a class from it may be referenced during execution and having it
     unloaded then may lead to a runtime doesNotUnderstand error, unless the caller
     includes explicit checks for the package being present.
     This method is generated automatically,
     by searching all classes (and their packages) which are referenced by my classes.
     Please also take a look at the #mandatoryPreRequisites method"

    ^ #(
        #'stx:goodies/xml/vw'    "XML::XMLParser - referenced by VDBVirtualMemoryMap>>initializeFromSysInternalsVmmapDump:"
        #'stx:libbasic2'    "List - referenced by VDBAbstractContainer>>initialize"
        #'stx:libtool2'    "MenuEditor - referenced by VDBIconLibrary class>>initialize"
    )
!

subProjects
    "list packages which are known as subprojects. 
     The generated makefile will enter those and make there as well.
     However: they are not forced to be loaded when a package is loaded; 
     for those, redefine requiredPrerequisites."

    ^ #(
    )
! !

!jv_vdb class methodsFor:'description - contents'!

classNamesAndAttributes
    "lists the classes which are to be included in the project.
     Each entry in the list may be: a single class-name (symbol),
     or an array-literal consisting of class name and attributes.
     Attributes are: #autoload or #<os> where os is one of win32, unix,..."

    ^ #(
        "<className> or (<className> attributes...) in load order"
        VDBAbstractApplication
        VDBAbstractPresenter
        VDBEvaluator
        VDBIconLibrary
        VDBSettingsApplication
        VDBVirtualMemoryMap
        VDBVirtualMemoryRegion
        VDBWindowsDebuggerConsoleView
        #'jv_vdb'
        VDBAbstractContainer
        VDBAbstractListApplication
        VDBAbstractUnixConsoleApplication
        VDBBreakpointApplication
        VDBBreakpointPresenter
        VDBDebuggerApplication
        VDBEventLogApplication
        VDBFrameApplication
        VDBFramePresenter
        VDBInstructionPresenter
        VDBInstructionsAndSourcePresenter
        VDBMemoryApplication
        VDBSourceApplication
        VDBThreadGroupPresenter
        VDBThreadPresenter
        VDBVariableObjectPresenter
        VDBWindowsDebuggerConsoleApplication
        VDBAbstractTreeApplication
        VDBBreakpointListApplication
        VDBTabbingContainer
        VDBUnixDebuggerConsoleApplication
        VDBUnixInferiorConsoleApplication
        VDBInstructionListApplication
        VDBStackApplication
        VDBVariableObjectListApplication
    )
!

extensionMethodNames
    "lists the extension methods which are to be included in the project.
     Entries are 2-element array literals, consisting of class-name and selector.
     A correponding method with real names must be present in my concrete subclasses
     if it has extensions."

    ^ #(
        GDBVariableObject inspector2TabVariable
        UserPreferences vdbFrameFiltersEnabled
        UserPreferences vdbFrameFiltersEnabled:
        UserPreferences vdbPrettyPrintingEnabled
        UserPreferences vdbPrettyPrintingEnabled:
    )
! !

!jv_vdb class methodsFor:'description - project information'!

companyName
    "Returns a company string which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info"

    ^ 'Jan Vrany'

    "Modified: / 23-11-2017 / 22:33:45 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

description
    "Returns a description string which will appear in nt.def / bc.def"

    ^ 'Visual / VM Debugger Library'

    "Modified: / 23-11-2017 / 22:34:15 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

legalCopyright
    "Returns a copyright string which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info"

    ^ 'Copyright (C) Jan Vrany 2015-now'

    "Modified (format): / 23-11-2017 / 22:36:05 / Jan Vrany <jan.vrany@fit.cvut.cz>"
!

productName
    "Returns a product name which will appear in <lib>.rc.
     Under win32, this is placed into the dlls file-info.
     This method is usually redefined in a concrete application definition"

    ^ self description

    "Modified: / 23-11-2017 / 22:36:32 / Jan Vrany <jan.vrany@fit.cvut.cz>"
! !

!jv_vdb class methodsFor:'documentation'!

version_HG
    ^ '$Changeset: <not expanded> $'
! !

